@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.57 2006/05/11 12:40:57 evertonm Exp $ */
+/* $Id: common.c,v 1.59 2006/05/12 19:06:47 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -28,10 +28,14 @@ MA 02110-1301 USA
 #include <assert.h>
 #include <errno.h>
 #include <sys/uio.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
 
 #include "common.h"
 #include "sock.h"
 #include "conf.h"
+#include "str.h"
 
 
 const char * const NEPIM_LABEL_PARTIAL      = "part";
@@ -41,7 +45,7 @@ const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
 const char *nepim_version()
 {
-  return "0.23";
+  return "0.24";
 }
 
 static void nepim_dump_stat(FILE *out, struct timeval now, const char *label,
@@ -368,3 +372,70 @@ void udp_check_packet_data(int sd, nepim_udp_hdr_t *hdr,
         }
     }
 }
+
+struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
+					  const char *list,
+					  struct sockaddr *addr,
+					  int *addr_len)
+{
+  int size = addr_list_size(list);
+  int i;
+
+  for (i = 0; i < size; ++i) {
+    char hostname[100];
+    const char *portname;
+    struct addrinfo hints;
+    struct addrinfo *ai_res;
+    struct addrinfo *ai;
+
+    if (addr_list_get(list, i, hostname, sizeof(hostname))) {
+      fprintf(stderr, 
+              "%s %s: failure parsing address %d/%d from list: %s\n",
+              __FILE__, __PRETTY_FUNCTION__,
+	      i, size, list);
+      continue;
+    }
+
+    /* split host/port */
+    if (addr_split_port(hostname, sizeof(hostname), &portname))
+      portname = 0; /* if port unspecified, ask OS for one */
+
+    memset(&hints, 0, sizeof(hints));
+
+    hints.ai_socktype = socktype;
+    hints.ai_protocol = proto;
+    hints.ai_flags    = AI_CANONNAME;
+    hints.ai_family   = PF_UNSPEC;
+
+    int result = getaddrinfo(hostname, portname,
+			     &hints, &ai_res);
+    if (result) {
+      fprintf(stderr, "%s %s: getaddrinfo(%s,%s): %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      hostname, portname ? portname : "0",
+	      gai_strerror(result));
+      continue;
+    }
+
+    for (ai = ai_res; ai; ai = ai->ai_next) {
+
+      if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
+	continue;
+
+      if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
+	continue;
+
+      memcpy(addr, ai->ai_addr, ai->ai_addrlen);
+      *addr_len = ai->ai_addrlen;
+
+      break;
+    }
+
+    freeaddrinfo(ai_res);
+
+    return addr;
+  }
+
+  return 0;
+}
+
