@@ -64,9 +64,6 @@ nepim_global_t nepim_global = {
   0x00,     /* fill_byte */
   0,        /* pause_duration */
   0,        /* password */
-  0,        /* udp_exp_stats */
-  0,        /* udp_exp_loss */
-  0,        /* udp_exp_dup */
   0,        /* tcpwrap */
   -1,       /* search_unix_socket (boolean) */
   -1,       /* soft_error_verbose (boolean) */
