@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.50 2006/05/11 12:40:57 evertonm Exp $
+  $Id: main.c,v 1.51 2006/05/12 19:06:47 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -84,6 +84,7 @@ static void usage(FILE *out, const char *prog_name)
           "common (client/server) options:\n"
           "  -h             help\n"
           "  -v             show program version\n"
+          "  -b addr-list   bind to specific addresses (defaults to any)\n"
           "  -p port        server port number (defaults to %s)\n"
           "  -m mode        path MTU discovery mode (defaults to %d)\n"
           "                 modes: -1 = use system-wide settings\n"
@@ -103,6 +104,7 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -q             quietly hide soft read/write errors\n"
 	  "  -y tos         ip tos (defaults to %d, tos=-1 means don't change)\n"
 	  "  -K udp-ka-time UDP keepalive timeout in ms (defaults to %ld ms)\n"
+	  "\n"
           "client-only options:\n"
           "  -u             UDP mode (defaults to TCP)\n"
           "  -s             client-send simplex mode (defaults to server-send)\n"
@@ -134,19 +136,22 @@ static void usage(FILE *out, const char *prog_name)
 	  "                 nagle: -1 = use system's default\n"
 	  "                         0 = off (enable TCP_NODELAY)\n"
 	  "                         1 = on (disable TCP_NODELAY)\n"
+	  "\n"
           "server-only options:\n"
           "  -f [lib-name]  enable TCP wrapper filtering\n"
-          "  -b addr-list   bind to specific addresses (defaults to any)\n"
           "  -j addr-list   join multicast groups (defaults to empty)\n"
 	  "  -U path-list   bind UNIX stream sockets to specified addresses\n"
 #if 0
 	  "  -G path-list   bind UNIX datagram sockets to specified addresses\n"
 #endif
-          "                 list: addr_1[,port_1][... addr_n[,port_n]]\n"
-          "                 examples:  -b '10.0.0.1 192.168.0.1,5000 ::1'\n"
-	  "                            -U '/tmp/sock1 /tmp/sock2'\n"
           "  -l backlog     TCP listen(2) backlog (defaults to %d)\n"
           "  -T mcast-ttl   TTL for multicast packets (defaults to system)\n"
+	  "\n"
+          "addr-list syntax: addr_1[,port_1][... addr_n[,port_n]]\n"
+          "                  examples: -c localhost\n"
+	  "                            -b '10.0.0.1 192.168.0.1,5000 ::1'\n"
+	  "                            -j ff01::1111\n"
+	  "                            -U '/tmp/sock1 /tmp/sock2'\n"
           ,
           nepim_global.prog_name, 
           nepim_global.portname,
